/*
 *   Search through the transport providers on the system.
 */

if ((handlep = setnetpath()) == NULL) {
    nc_perror(argv[0]);
    exit(1);
}

while ((netconfigp = getnetpath(handlep)) != NULL) {

    /*
     *  Only check for connectionless transports.
     */

    if (netconfigp->nc_semantics == NC_TPI_CLTS) {

        /*
         *  Attempt to open the device and bind to an
         *  endpoint.  If either of the operations fails,
         *  continue the loop to get the next transport
         *  provider.
         */

        if ((fd = t_open(netconfigp->nc_device, O_RDWR,
                         NULL)) == -1) {
            continue;
        }
        if (t_bind(fd, (struct t_bind *)NULL,
                   (struct t_bind *)NULL) == -1) {
            (void) t_close(fd);
            continue;
        }

        /* 
         * Do protocol-specific negotiating for broadcast.
         * netdir_options returns 0 on success, nonzero
         * on failure.
         */

        if (netdir_options(netconfigp,
                      ND_SET_BROADCAST, fd, NULL) == 0) {
            break;
        }
        (void) t_close(fd);
    }
}

if (netconfigp == NULL) {
    fprintf(stderr, "could not find a connectionless
                     transport that supports broadcast\n");
    exit(1);
}

nd_hostserv.h_host = HOST_BROADCAST;
nd_hostserv.h_serv = "library";

if (netdir_getbyname(netcfp, &nd_hostserv,
                                    &nd_addrlistp) != 0) {
        netdir_perror("No addresses found");
        exit(1);
}

endnetconfig(handlep);
